==> plotly-3.2.0a2-py2.py3-none-any.whl: plotly/validators/histogram2dcontour/__init__.py <==
from ._zsrc import ZsrcValidator
from ._zmin import ZminValidator
from ._zmax import ZmaxValidator
from ._zhoverformat import ZhoverformatValidator
from ._zauto import ZautoValidator
from ._z import ZValidator
from ._ysrc import YsrcValidator
from ._ycalendar import YcalendarValidator
from ._ybins import YBinsValidator
from ._yaxis import YAxisValidator
from ._y import YValidator
from ._xsrc import XsrcValidator
from ._xcalendar import XcalendarValidator
from ._xbins import XBinsValidator
from ._xaxis import XAxisValidator
from ._x import XValidator
from ._visible import VisibleValidator
from ._uid import UidValidator
from ._stream import StreamValidator
from ._showscale import ShowscaleValidator
from ._showlegend import ShowlegendValidator
from ._selectedpoints import SelectedpointsValidator
from ._reversescale import ReversescaleValidator
from ._opacity import OpacityValidator
from ._ncontours import NcontoursValidator
from ._nbinsy import NbinsyValidator
from ._nbinsx import NbinsxValidator
from ._name import NameValidator
from ._marker import MarkerValidator
from ._line import LineValidator
from ._legendgroup import LegendgroupValidator
from ._idssrc import IdssrcValidator
from ._ids import IdsValidator
from ._hoverlabel import HoverlabelValidator
from ._hoverinfosrc import HoverinfosrcValidator
from ._hoverinfo import HoverinfoValidator
from ._histnorm import HistnormValidator
from ._histfunc import HistfuncValidator
from ._customdatasrc import CustomdatasrcValidator
from ._customdata import CustomdataValidator
from ._contours import ContoursValidator
from ._colorscale import ColorscaleValidator
from ._colorbar import ColorBarValidator
from ._autocontour import AutocontourValidator
from ._autocolorscale import AutocolorscaleValidator
from ._autobiny import AutobinyValidator
from ._autobinx import AutobinxValidator

==> plotly-3.7.0rc1-py2.py3-none-any.whl: plotly/validators/histogram2dcontour/__init__.py <==
from ._zsrc import ZsrcValidator
from ._zmin import ZminValidator
from ._zmid import ZmidValidator
from ._zmax import ZmaxValidator
from ._zhoverformat import ZhoverformatValidator
from ._zauto import ZautoValidator
from ._z import ZValidator
from ._ysrc import YsrcValidator
from ._ycalendar import YcalendarValidator
from ._ybins import YBinsValidator
from ._yaxis import YAxisValidator
from ._y import YValidator
from ._xsrc import XsrcValidator
from ._xcalendar import XcalendarValidator
from ._xbins import XBinsValidator
from ._xaxis import XAxisValidator
from ._x import XValidator
from ._visible import VisibleValidator
from ._uirevision import UirevisionValidator
from ._uid import UidValidator
from ._stream import StreamValidator
from ._showscale import ShowscaleValidator
from ._showlegend import ShowlegendValidator
from ._selectedpoints import SelectedpointsValidator
from ._reversescale import ReversescaleValidator
from ._opacity import OpacityValidator
from ._ncontours import NcontoursValidator
from ._nbinsy import NbinsyValidator
from ._nbinsx import NbinsxValidator
from ._name import NameValidator
from ._marker import MarkerValidator
from ._line import LineValidator
from ._legendgroup import LegendgroupValidator
from ._idssrc import IdssrcValidator
from ._ids import IdsValidator
from ._hovertemplatesrc import HovertemplatesrcValidator
from ._hovertemplate import HovertemplateValidator
from ._hoverlabel import HoverlabelValidator
from ._hoverinfosrc import HoverinfosrcValidator
from ._hoverinfo import HoverinfoValidator
from ._histnorm import HistnormValidator
from ._histfunc import HistfuncValidator
from ._customdatasrc import CustomdatasrcValidator
from ._customdata import CustomdataValidator
from ._contours import ContoursValidator
from ._colorscale import ColorscaleValidator
from ._colorbar import ColorBarValidator
from ._autocontour import AutocontourValidator
from ._autocolorscale import AutocolorscaleValidator
from ._autobiny import AutobinyValidator
from ._autobinx import AutobinxValidator
